==> webHotfixV1.1.0.tar: icpdas/httpd/page/net_gprs.php <==

<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//====================================
//== get and setting GPRS parameter ==
//====================================

require_once("./class.php");

if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$cpin = trim($_POST["modem_pin"]);
	$phone = trim($_POST["gprs_phone"]);
	$apn = trim($_POST["gprs_apn"]);
	$user = trim($_POST["gprs_user"]);
	$password = trim($_POST["gprs_password"]);
	$enable = $_POST["enable"];

	if(strlen($cpin) == 4)
		setPINCode($cpin);
	else
	{
		echo "<div align=\"center\"><font color=\"#cc0000\">PIN Code Length Error!!</font><br>\n";
		exit;
	}

	setpppdCfg($phone, $apn, $user, $password);
	echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";

	//enable auto-dialing function
	setpppdRule($enable);

}

//READ INFORMATION
//-- cpin
getPINCode($cpin);
//-- ppp config : APN, phone, user, password
getpppdCfg($phone, $apn, $user, $password);
//-- get pppd rule
getpppdRule($enable);
?>


	<br>
	<form method="post" name="ethernet"><br><!-- 加入 action="aa.html" 可以指定給誰處理 -->
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="2" bgcolor="#ffcc99">2G/3G Configure<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="200">PIN Code</td>
			<td ><input size="20" name="modem_pin" type="password" value="<?php echo $cpin;?>" ><br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Phone Number</td>
			<td ><input size="20" name="gprs_phone" value="<?php echo $phone;?>" >(1)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">APN</td>
			<td ><input size="20" name="gprs_apn" value="<?php echo $apn;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">User Name</td>
			<td ><input size="20" name="gprs_user" value="<?php echo $user;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Password</td>
			<td ><input size="20" name="gprs_password" value="<?php echo $password;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Auto-Dialing</td>
			<td ><input size="20" name="enable" type="checkbox" value="enable"<?php if($enable=="enable") echo "checked";?> >Enable <br>
			</td>
		</tr>

		<tr align="center">
			<td colspan="2"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		<tr>
			<td colspan="2">
			(1):usually use <font color="#cc0000">*99#</font> or <font color="#cc0000">*99***1#</font><br>
			(2):please ask your SIM Card provider<br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>
</body>
</html>

==> webHotfixV1.3.0_2015-08-25.tar: icpdas/httpd/page/net_gprs.php <==

<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
<?php
//====================================
//== get and setting GPRS parameter ==
//====================================

require_once("./class.php");

if($_POST["submit"]=="Modify")	//press "Modify" button
{
	$cpin = trim($_POST["modem_pin"]);
	$phone = trim($_POST["gprs_phone"]);
	$apn = trim($_POST["gprs_apn"]);
	$user = trim($_POST["gprs_user"]);
	$password = trim($_POST["gprs_password"]);
	$net_mode = $_POST["net_mode"];
	$enable = $_POST["enable"];

	if(strlen($cpin) == 4)
		setPINCode($cpin);
	else
	{
		echo "<div align=\"center\"><font color=\"#cc0000\">PIN Code Length Error!!</font><br>\n";
		exit;
	}

	setpppdCfg($phone, $apn, $user, $password, $net_mode);
	echo "<div align=\"center\"><font color=\"#cc0000\">setting success!!</font><br>\n";
	exec('echo -e "' .$net_mode .'"\r\n" > /dev/ttyUSB2');

	//enable auto-dialing function
	setpppdRule($enable);

}

//READ INFORMATION
//-- cpin
getPINCode($cpin);
//-- ppp config : APN, phone, user, password
getpppdCfg($phone, $apn, $user, $password, $net_mode);
//-- get pppd rule
getpppdRule($enable);
?>


	<br>
	<form method="post" name="ethernet"><br><!-- 加入 action="aa.html" 可以指定給誰處理 -->
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="2" bgcolor="#ffcc99">2G/3G Configure<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="200">PIN Code</td>
			<td ><input size="20" name="modem_pin" type="password" value="<?php echo $cpin;?>" ><br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Phone Number</td>
			<td ><input size="20" name="gprs_phone" value="<?php echo $phone;?>" >(1)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">APN</td>
			<td ><input size="20" name="gprs_apn" value="<?php echo $apn;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">User Name</td>
			<td ><input size="20" name="gprs_user" value="<?php echo $user;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Password</td>
			<td ><input size="20" name="gprs_password" value="<?php echo $password;?>" >(2)<br>
			</td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="200">Net Mode</td>
			<td >
				<select name="net_mode">
				<option value="AT+CNMP=2" <?php if($net_mode == "AT+CNMP=2") echo "selected"; ?> >Automatic</option>
				<option value="AT+CNMP=14" <?php if($net_mode == "AT+CNMP=14") echo "selected"; ?> >WCDMA (3G) Only</option>
				<option value="AT+CNMP=13" <?php if($net_mode == "AT+CNMP=13") echo "selected"; ?> >GSM (2G) Only</option>
				</select>
			<br>
			</td>
		</tr>


		<tr>
			<td bgcolor="#ccffff">Auto-Dialing</td>
			<td ><input size="20" name="enable" type="checkbox" value="enable"<?php if($enable=="enable") echo "checked";?> >Enable <br>
			</td>
		</tr>

		<tr align="center">
			<td colspan="2"><input name="submit" value="Modify" type="submit"><br>
			</td>
		</tr>

		<tr>
			<td colspan="2">
			(1) usually use <font color="#cc0000">*99#</font> or <font color="#cc0000">*99***1#</font><br>
			(2) please ask your SIM Card provider<br>
			(3) Net Mode: Automatic will use 3G first, if no 3G network, it will change to 2G<br>
			</td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>
	<br>
	<br>
</body>
</html>
